==> payroll_ver_3.2.2.zip: payroll3/src/jp/mosp/payroll/dao/DetailTimeDao.java <==
package jp.mosp.payroll.dao;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Properties;

import jp.mosp.common.dto.CmAspUserDto;
import jp.mosp.common.dto.CmUserDto;
import jp.mosp.payroll.base.PayrollDao;
import jp.mosp.payroll.dto.DetailTimeDto;

/**
 * e햾׃e[u𑀍@\񋟂B<br><br>
 * {@link DetailTimeDto}pāADBJavavOԂŃR[hLB<br>
 */
public class DetailTimeDao extends PayrollDao {
	
	/**
	 *  L[1B<br>
	 */
	public static final String KEY_01 = "KCODE";
	
	/**
	 *  L[2B<br>
	 */
	public static final String KEY_02 = "CALC_DATE";
	
	/**
	 *  L[3B<br>
	 */
	public static final String KEY_03 = "DETAIL_CODE";
	
	public static final String COL_KCODE         = "KCODE"      ;
	public static final String COL_CALC_DATE     = "CALC_DATE"  ;
	public static final String COL_DETAIL_CODE   = "DETAIL_CODE";
	public static final String COL_AMOUNT        = "AMOUNT"     ;
	
	/**
	 * {@link PayrollDao#PayrollDao(Properties, String, CmAspUserDto, CmUserDto, Connection)}
	 * sB<br>
	 * @param cfg     ݒt@C
	 * @param cmd     R}h
	 * @param aspUser ASP[U[
	 * @param user    [U[
	 * @param conn    DBRlNV
	 */
	public DetailTimeDao(
			Properties   cfg,
			String       cmd,
			CmAspUserDto aspUser,
			CmUserDto    user,
			Connection   conn
	) {
		super(cfg, cmd, aspUser, user, conn);
	}
	
	/**
	 * ʂDTOƂĎ擾B<br>
	 * @return R[h(DTO)
	 * @throws SQLException
	 */
	private DetailTimeDto mapping() throws SQLException {
		DetailTimeDto dto = new DetailTimeDto();
		dto.setKCode     (rs.getString(COL_KCODE       ));
		dto.setCalcDate  (rs.getDate  (COL_CALC_DATE   ));
		dto.setDetailCode(rs.getString(COL_DETAIL_CODE ));
		dto.setAmount    (rs.getFloat (COL_AMOUNT      ));
		mappingCommonInfo(dto);
		return dto;
	}
	
	/**
	 * ʂDTOListƂĎ擾B<br>
	 * @return ʃXg
	 * @throws SQLException
	 */
	private List<DetailTimeDto> mappingAll() throws SQLException {
		List<DetailTimeDto> all = new ArrayList<DetailTimeDto>();
		while (rs.next()) {
			all.add(mapping());
		}
		return all;
	}
	
	/**
	 * ɂf[^擾B<br>
	 * @param kCode    ЈR[h
	 * @param calcDate vZN
	 * @return (DTOList)
	 * @throws SQLException 
	 * @throws IllegalAccessException 
	 * @throws NoSuchFieldException 
	 */
	public List<DetailTimeDto> find(
			String kCode, Date calcDate
	) throws SQLException, NoSuchFieldException, IllegalAccessException {
		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("WHERE ");
		sb.append(COL_KCODE + " = ? ");
		sb.append("AND ");
		sb.append(COL_CALC_DATE + " = ? ");
		try {
			prepareStatement(getSelectQuery(getClass()) + sb.toString());
			setParam    (index++, kCode    );
			setDateParam(index++, calcDate);
			executeQuery();
			return mappingAll();
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * ɂf[^擾B<br>
	 * @param calcDate vZN
	 * @return (DTOList)
	 * @throws SQLException 
	 * @throws IllegalAccessException 
	 * @throws NoSuchFieldException 
	 */
	public List<DetailTimeDto> find(
			Date calcDate
	) throws SQLException, NoSuchFieldException, IllegalAccessException {
		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("WHERE ");
		sb.append(COL_CALC_DATE + " = ? ");
		try {
			prepareStatement(getSelectQuery(getClass()) + sb.toString());
			setDateParam(index++, calcDate);
			executeQuery();
			return mappingAll();
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * f[^}B<br>
	 * @param list }ΏۃXg
	 * @return int }()
	 * @throws SQLException
	 * @throws IllegalAccessException
	 * @throws NoSuchFieldException 
	 */
	public int insert(
			List<?> list
	) throws SQLException, IllegalAccessException, NoSuchFieldException {
		try {
			if (list == null || list.size() == 0) {
				return 0;
			}
			int count = 0;
			int max = 3;	// xɍXV郌R[h̍ől
			// }
			index = 1;
			prepareStatement(getInsertQuery(getClass(), list.size(), max));
			for (int i = 0; i < list.size(); i++) {
				setParams((DetailTimeDto)list.get(i), true);
				executeUpdate(getClass(), list.size(), max, i);
				count += cnt;
			}
			return count;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * ɂ폜sB
	 * @param calcDate vZN
	 * @return 폜()
	 * @throws SQLException 
	 * @throws IllegalAccessException 
	 * @throws NoSuchFieldException 
	 */
	public int delete(
			Date calcDate
	) throws SQLException, NoSuchFieldException, IllegalAccessException {
		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("DELETE FROM " + getTable(getClass()) + " ");
		sb.append("WHERE ");
		sb.append(COL_CALC_DATE + " = ? ");
		try {
			prepareStatement(sb.toString());
			setDateParam(index++, calcDate);
			executeUpdate(false);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * ɂ폜sB
	 * @param kCode    ЈR[h
	 * @param calcDate vZN
	 * @return 폜()
	 * @throws SQLException 
	 * @throws IllegalAccessException 
	 * @throws NoSuchFieldException 
	 */
	public int delete(
			String kCode, Date calcDate
	) throws SQLException, NoSuchFieldException, IllegalAccessException {
		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("DELETE FROM " + getTable(getClass()) + " ");
		sb.append("WHERE ");
		sb.append(COL_KCODE + " = ? ");
		sb.append("AND ");
		sb.append(COL_CALC_DATE+ " = ? ");
		try {
			prepareStatement(sb.toString());
			setParam    (index++, kCode    );
			setDateParam(index++, calcDate);
			executeUpdate(false);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * p[^ݒ肷B<br>
	 * @param dto      XVΏDTO
	 * @param isInsert }tO(trueF}AfalseFXV)
	 * @throws SQLException
	 */
	private void setParams(DetailTimeDto dto, boolean isInsert) throws SQLException {
		setParam    (index++, dto.getKCode     ());
		setDateParam(index++, dto.getCalcDate  ());
		setParam    (index++, dto.getDetailCode());
		setParam    (index++, dto.getAmount    ());
		setCommonParams(isInsert);
	}

}

==> payroll_ver_3.3.0.zip: payroll3/src/jp/mosp/payroll/dao/DetailTimeDao.java <==
package jp.mosp.payroll.dao;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Properties;

import jp.mosp.common.dto.CmAspUserDto;
import jp.mosp.common.dto.CmUserDto;
import jp.mosp.payroll.base.PayrollDao;
import jp.mosp.payroll.dto.DetailTimeDto;

/**
 * e햾׃e[u𑀍@\񋟂B<br><br>
 * {@link DetailTimeDto}pāADBJavavOԂŃR[hLB<br>
 */
public class DetailTimeDao extends PayrollDao {
	
	/**
	 *  L[1B<br>
	 */
	public static final String	KEY_01			= "KCODE";
	
	/**
	 *  L[2B<br>
	 */
	public static final String	KEY_02			= "CALC_DATE";
	
	/**
	 *  L[3B<br>
	 */
	public static final String	KEY_03			= "DETAIL_CODE";
	
	public static final String	COL_KCODE		= "KCODE";
	public static final String	COL_CALC_DATE	= "CALC_DATE";
	public static final String	COL_DETAIL_CODE	= "DETAIL_CODE";
	public static final String	COL_AMOUNT		= "AMOUNT";
	

	/**
	 * {@link PayrollDao#PayrollDao(Properties, String, CmAspUserDto, CmUserDto, Connection)}
	 * sB<br>
	 * @param cfg     ݒt@C
	 * @param cmd     R}h
	 * @param aspUser ASP[U[
	 * @param user    [U[
	 * @param conn    DBRlNV
	 */
	public DetailTimeDao(Properties cfg, String cmd, CmAspUserDto aspUser, CmUserDto user, Connection conn) {
		super(cfg, cmd, aspUser, user, conn);
	}
	
	/**
	 * ʂDTOƂĎ擾B<br>
	 * @return R[h(DTO)
	 * @throws SQLException
	 */
	private DetailTimeDto mapping() throws SQLException {
		DetailTimeDto dto = new DetailTimeDto();
		dto.setKCode(rs.getString(COL_KCODE));
		dto.setCalcDate(rs.getDate(COL_CALC_DATE));
		dto.setDetailCode(rs.getString(COL_DETAIL_CODE));
		dto.setAmount(rs.getFloat(COL_AMOUNT));
		mappingCommonInfo(dto);
		return dto;
	}
	
	/**
	 * ʂDTOListƂĎ擾B<br>
	 * @return ʃXg
	 * @throws SQLException
	 */
	private List<DetailTimeDto> mappingAll() throws SQLException {
		List<DetailTimeDto> all = new ArrayList<DetailTimeDto>();
		while (rs.next()) {
			all.add(mapping());
		}
		return all;
	}
	
	/**
	 * ɂf[^擾B<br>
	 * @param kCode    ЈR[h
	 * @param calcDate vZN
	 * @return (DTOList)
	 * @throws SQLException 
	 * @throws IllegalAccessException 
	 * @throws NoSuchFieldException 
	 */
	public List<DetailTimeDto> find(String kCode, Date calcDate) throws SQLException, NoSuchFieldException,
			IllegalAccessException {
		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("WHERE ");
		sb.append(COL_KCODE + " = ? ");
		sb.append("AND ");
		sb.append(COL_CALC_DATE + " = ? ");
		try {
			prepareStatement(getSelectQuery(getClass()) + sb.toString());
			setParam(index++, kCode);
			setDateParam(index++, calcDate);
			executeQuery();
			return mappingAll();
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * ɂf[^擾B<br>
	 * @param calcDate vZN
	 * @return (DTOList)
	 * @throws SQLException 
	 * @throws IllegalAccessException 
	 * @throws NoSuchFieldException 
	 */
	public List<DetailTimeDto> find(Date calcDate) throws SQLException, NoSuchFieldException, IllegalAccessException {
		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("WHERE ");
		sb.append(COL_CALC_DATE + " = ? ");
		try {
			prepareStatement(getSelectQuery(getClass()) + sb.toString());
			setDateParam(index++, calcDate);
			executeQuery();
			return mappingAll();
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * f[^}B<br>
	 * @param list }ΏۃXg
	 * @return int }()
	 * @throws SQLException
	 * @throws IllegalAccessException
	 * @throws NoSuchFieldException 
	 */
	public int insert(List<?> list) throws SQLException, IllegalAccessException, NoSuchFieldException {
		try {
			if (list == null || list.size() == 0) {
				return 0;
			}
			int count = 0;
			int max = 3; // xɍXV郌R[h̍ől
			// }
			index = 1;
			prepareStatement(getInsertQuery(getClass(), list.size(), max));
			for (int i = 0; i < list.size(); i++) {
				setParams((DetailTimeDto)list.get(i), true);
				executeUpdate(getClass(), list.size(), max, i);
				count += cnt;
			}
			return count;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * ɂ폜sB
	 * @param calcDate vZN
	 * @return 폜()
	 * @throws SQLException 
	 * @throws IllegalAccessException 
	 * @throws NoSuchFieldException 
	 */
	public int delete(Date calcDate) throws SQLException, NoSuchFieldException, IllegalAccessException {
		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("DELETE FROM " + getTable(getClass()) + " ");
		sb.append("WHERE ");
		sb.append(COL_CALC_DATE + " = ? ");
		try {
			prepareStatement(sb.toString());
			setDateParam(index++, calcDate);
			executeUpdate(false);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * ɂ폜sB
	 * @param kCode    ЈR[h
	 * @param calcDate vZN
	 * @return 폜()
	 * @throws SQLException 
	 * @throws IllegalAccessException 
	 * @throws NoSuchFieldException
	 */
	public int delete(String kCode, Date calcDate) throws SQLException, NoSuchFieldException, IllegalAccessException {
		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("DELETE FROM " + getTable(getClass()) + " ");
		sb.append("WHERE ");
		sb.append(COL_KCODE + " = ? ");
		sb.append("AND ");
		sb.append(COL_CALC_DATE + " = ? ");
		try {
			prepareStatement(sb.toString());
			setParam(index++, kCode);
			setDateParam(index++, calcDate);
			executeUpdate(false);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * p[^ݒ肷B<br>
	 * @param dto      XVΏDTO
	 * @param isInsert }tO(trueF}AfalseFXV)
	 * @throws SQLException
	 */
	private void setParams(DetailTimeDto dto, boolean isInsert) throws SQLException {
		setParam(index++, dto.getKCode());
		setDateParam(index++, dto.getCalcDate());
		setParam(index++, dto.getDetailCode());
		setParam(index++, dto.getAmount());
		setCommonParams(isInsert);
	}
	
}
